function [C, sigma] = dataset3Params(X, y, Xval, yval)

%   DATASET3PARAMS returns your choice of C and sigma for Part 7 where you 
%   select the optimal (C, sigma) learning parameters to use for SVM with RBF kernel
%   [C, sigma] = DATASET3PARAMS(X, y, Xval, yval) returns your choice of C and sigma. 
%   You should complete this function to return the optimal C and sigma based on
%   a cross-validation set.

% initialisation
Tab_Val = [0.01 0.03 0.1 0.3 1 3 10 30];
C = 0; sigma = 0; ErreurOpt = 1;
% Recherche de C optimal & Sigma optimal
for k_C = Tab_Val
    for k_S = Tab_Val
        % Détermination d'un modèle avec le training set en utilisant le SVM
        model = svmTrain(X, y, k_C, @(x1, x2) gaussianKernel(x1, x2, k_S)); 
        % Predictions obtenues avec le modèle et le cross validation set
        predictions = svmPredict(model, Xval);
        % Calcul de l'erreur moyenne correspondante
        pred_error = mean(double(predictions ~= yval));
        % Affectation du C optimal & Sigma optimal
        if pred_error < ErreurOpt
            C = k_C ; sigma = k_S;
            ErreurOpt = pred_error;
        end
    end
end

end
 