function word_indices = processEmail(email_contents)

%   PROCESSEMAIL preprocesses the body of an email and returns a list of indices 
%   word_indices = PROCESSEMAIL(email_contents) preprocesses the body of an email 
%   and returns a list of indices of the words contained in the email. 

% Load Vocabulary
vocabList = getVocabList();

% Init return value
% word_indices = [];
word_indices = zeros(length(vocabList),1);
nb_mots = 0;

%% Preprocess Email 

% Find the Headers (\n\n and remove) : if you are working with raw emails with the full headers
% hdrstart = strfind(email_contents, ([char(10) char(10)]));
% email_contents = email_contents(hdrstart(1):end);

% Lower case : The entire email is converted into lower case
email_contents = lower(email_contents);

% Strip all HTML : Remove all the HTML tags, so that only the content remains
% Looks for any expression that starts with < and ends with > and replace
% and does not have any < or > in the tag it with a space
email_contents = regexprep(email_contents, '<[^<>]+>', ' ');

% Handle Numbers : Look for one or more characters between 0-9
% and replace with the text "number"
email_contents = regexprep(email_contents, '[0-9]+', 'number');

% Handle URLS : Look for strings starting with http:// or https://
% and replace with the text “httpaddr”
email_contents = regexprep(email_contents, '(http|https)://[^\s]*', 'httpaddr');

% Handle Email Addresses : Look for strings with @ in the middle 
% and replace with the text “emailaddr”
email_contents = regexprep(email_contents, '[^\s]+@[^\s]+', 'emailaddr');

% Handle $ sign : All dollar signs ($) are replaced with the text "dollar"
email_contents = regexprep(email_contents, '[$]+', 'dollar');


%% Tokenize Email (découpage en unités lexicales)

% Output the email to screen as well
fprintf('\n==== Processed Email ====\n\n');

% Process file
l = 0;
while ~isempty(email_contents)

    % Tokenize and also get rid of any punctuation
    [str, email_contents] = strtok(email_contents, [' @$/#.-:&*+=[]?!(){},''">_<;%' char(10) char(13)]);
   
    % Remove any non alphanumeric characters
    str = regexprep(str, '[^a-zA-Z0-9]', '');

    % Stem the word (the porterStemmer sometimes has issues, so we use a try catch block)
    try str = porterStemmer(strtrim(str)); 
    catch str = ''; continue;
    end;

    % Skip the word if it is too short
    if length(str) < 1
       continue;
    end

    % Look up the word in the dictionary and add to word_indices if found
    % add the index of str to word_indices if it is in the vocabulary :
    
    % you have a stemmed word from the email in the variable str
    % You should look up str in the vocabulary list (vocabList).
    % If a match exists, you should add the index of the word to the  word_indices vector. 
    
    % Concretely, if str = 'action', then you should look up the vocabulary
    % list to find where in vocabList 'action' appears.  
    % For example, if vocabList{18} = 'action', then, you should add 18 
    % to the word_indices vector (word_indices = [word_indices ; 18];)
    for k_ind = 1:length(vocabList)
        if strcmp(str, vocabList{k_ind}) == 1
            % word_indices = [word_indices ; k_ind];
            nb_mots = nb_mots + 1;
            word_indices(nb_mots) = k_ind;
        end
    end

    % Print to screen, ensuring that the output lines are not too long
    if (l + length(str) + 1) > 78
        fprintf('\n');
        l = 0;
    end
    fprintf('%s ', str);
    l = l + length(str) + 1;

end
word_indices(nb_mots+1:end) = [];

% Print footer
fprintf('\n\n=========================\n');

end
